@@ -442,6 +442,9 @@ void server::confirm(void)
         node.next();
     }
 
+    if(!sipadmin && !sipusers)
+        return;
+
 #ifdef  HAVE_PWD_H
     ifcount = 0;
     char *member;
@@ -458,7 +461,7 @@ void server::confirm(void)
         grp = getgrnam(sipusers);
 
     // if no separated privilege, then use sipadmin
-    if(!grp)
+    if(!grp && sipadmin)
         grp = getgrnam(sipadmin);
 
     if(grp && !grp->gr_mem)
@@ -481,7 +484,8 @@ void server::confirm(void)
         addNode(leaf, "id", member);
     }
 
-    grp = getgrnam(sipadmin);
+    if(sipadmin)
+        grp = getgrnam(sipadmin);
 
     node = base->getFirst();
     while(is(node)) {
@@ -617,6 +621,63 @@ stack::subnet *server::getSubnet(const char *id)
     return NULL;
 }
 
+void server::listPolicy(FILE *fp)
+{
+    linked_pointer<stack::subnet> pp;
+    char buf[128], baddr[128], bmask[128];
+    struct sockaddr_storage addr, mask;
+    struct sockaddr_in *ipv4;
+#ifdef  AF_INET6
+    struct sockaddr_in6 *ipv6;
+#endif
+    inethostaddr_t ha;
+
+    locking.access();
+    pp = ((server *)(cfg))->acl;
+    while(is(pp)) {
+        const char *id = pp->getId();
+        int fam = pp->getFamily();
+        switch(fam) {
+#ifdef  AF_INET6
+        case AF_INET6:
+            ipv6 = (struct sockaddr_in6 *)&addr;
+            ha = pp->getNetwork();
+            memcpy(&ipv6->sin6_addr, &ha, sizeof(ipv6->sin6_addr));
+            ipv6->sin6_family = AF_INET6;
+            Socket::getaddress((struct sockaddr *)ipv6, baddr, sizeof(baddr));
+            ipv6 = (struct sockaddr_in6 *)&mask;
+            ha = pp->getNetmask();
+            memcpy(&ipv6->sin6_addr, &ha, sizeof(ipv6->sin6_addr));
+            ipv6->sin6_family = AF_INET6;
+            Socket::getaddress((struct sockaddr *)ipv4, bmask, sizeof(bmask));
+            break;
+#endif
+        case AF_INET:
+            ipv4 = (struct sockaddr_in *)&addr;
+            ha = pp->getNetwork();
+            memcpy(&ipv4->sin_addr, &ha, sizeof(ipv4->sin_addr));
+            ipv4->sin_family = AF_INET;
+            Socket::getaddress((struct sockaddr *)ipv4, baddr, sizeof(baddr));
+            ipv4 = (struct sockaddr_in *)&mask;
+            ha = pp->getNetmask();
+            memcpy(&ipv4->sin_addr, &ha, sizeof(ipv4->sin_addr));
+            ipv4->sin_family = AF_INET;
+            Socket::getaddress((struct sockaddr *)ipv4, bmask, sizeof(bmask));
+            break;
+        default:
+            String::set(baddr, sizeof(baddr), "?");
+            String::set(bmask, sizeof(bmask), "?");
+        }
+        Socket::getaddress(pp->getInterface(), buf, sizeof(buf));
+        if(pp->offline())
+            fprintf(fp, "offline %s; interface=%s, %s/%s\n", id, buf, baddr, bmask);
+        else
+            fprintf(fp, "policy %s; interface=%s, %s/%s\n", id, buf, baddr, bmask);
+        pp.next();
+    }
+    locking.release();
+}
+
 stack::subnet *server::getPolicy(struct sockaddr *addr)
 {
     assert(addr != NULL);
@@ -990,6 +1051,7 @@ void server::stop(void)
 void server::run(void)
 {
     int argc;
+    char buf[256];
     char *argv[65];
     char *state;
     char *cp, *tokens;
@@ -1052,8 +1114,6 @@ void server::run(void)
                 continue;
             }
 
-            char buf[256];
-
             while(fgets(buf, sizeof(buf), log) != NULL) {
                 cp = String::strip(buf, " \t\r\n");
                 fprintf(out, "%s\n", cp);
@@ -1168,6 +1228,27 @@ invalid:
             continue;
         }
 
+        if(ieq(argv[0], "policy") || ieq(argv[0], "network")) {
+            if(argc != 1)
+                goto invalid;
+            FILE *out = control::output(NULL);
+            if(!out)
+                continue;
+            struct sockaddr_storage peer;
+            service::published(&peer);
+            Socket::getaddress((struct sockaddr *)&peer, buf, sizeof(buf));
+            if(service::getInterface())
+                fprintf(out, "binding to %s:%u\n", service::getInterface(), service::getPort());
+            else
+                fprintf(out, "binding to *:%u\n", service::getPort());
+            if(buf[0])
+                fprintf(out, "peering as %s\n", buf);
+
+            listPolicy(out);
+            fclose(out);
+            continue;
+        }
+
         if(ieq(argv[0], "address")) {
             if(argc != 2)
                 goto invalid;
