@@ -79,7 +79,7 @@ void signals::run(void)
 #endif
         alarm(0);
         if(shutdown)
-            return;
+            break;
 
         shell::log(DEBUG1, "received signal %d", signo);
 
@@ -236,7 +236,10 @@ void notify::start(void)
     if(!dirpath)
         dirpath = control::env("prefix");
 
-    thread.background();
+    if(fsys::isdir(dirpath))
+        thread.background();
+    else
+        shell::log(shell::ERR, "notify failed; %s missing", dirpath);
 }
 
 void notify::run(void)
@@ -249,7 +252,7 @@ void notify::run(void)
     shell::log(DEBUG1, "notify watching %s", dirpath);
 
     watcher = inotify_init();
-    dirnode = inotify_add_watch(watcher, dirpath, IN_CLOSE_WRITE|IN_MOVED_TO|IN_MOVED_FROM|IN_DELETE);
+    dirnode = inotify_add_watch(watcher, dirpath, IN_CLOSE_WRITE|IN_MOVED_TO|IN_MOVED_FROM|IN_DELETE|IN_DONT_FOLLOW);
 
     while(watcher != -1) {
         // we want 500 ms of inactivity before actual updating...
@@ -305,6 +308,11 @@ void notify::run(void)
                     shell::log(DEBUG2, "%s updated", event->name);
                     ++updates;
                 }
+                else if(eq(event->name, "reload")) {
+                    shell::log(DEBUG2, "reload requested");
+                    control::send("reload");
+                    updates = 0;
+                }
                 offset += sizeof(struct inotify_event) + event->len;
             }
         }
